@@ -117,20 +117,6 @@ fn nrs_register_should_return_an_error_if_a_subname_is_specified() -> Result<()>
     Ok(())
 }
 
-#[test]
-fn nrs_register_should_return_an_error_if_an_invalid_link_is_specified() -> Result<()> {
-    let topname = get_random_nrs_string();
-    safe_cmd(["nrs", "register", &topname, "--link", "invalid"], Some(1))?
-        .assert()
-        .stderr(predicate::str::contains(
-            "The supplied link was not a valid url.",
-        ))
-        .stderr(predicate::str::contains(
-            "Run the command again with a valid url for the --link argument.",
-        ));
-    Ok(())
-}
-
 #[test]
 fn nrs_register_should_return_an_error_if_link_to_versioned_content_has_no_version() -> Result<()> {
     let with_trailing_slash = true;
@@ -498,22 +484,6 @@ fn nrs_add_with_default_should_return_an_error_if_link_to_versioned_content_has_
     Ok(())
 }
 
-#[test]
-fn nrs_add_should_return_an_error_if_an_invalid_link_is_specified() -> Result<()> {
-    let topname = get_random_nrs_string();
-    let public_name = format!("test.{}", &topname);
-    safe_cmd(["nrs", "register", &topname], Some(0))?;
-    safe_cmd(["nrs", "add", &public_name, "--link", "invalid"], Some(1))?
-        .assert()
-        .stderr(predicate::str::contains(
-            "The supplied link was not a valid url.",
-        ))
-        .stderr(predicate::str::contains(
-            "Run the command again with a valid url for the --link argument.",
-        ));
-    Ok(())
-}
-
 ///
 /// `nrs remove` subcommand
 ///
